# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2
from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.apis.meta.v1 import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime.schema import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDgithub.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x12\x34github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1\x1aGgithub.com/metaprov/modelaapi/pkg/apis/catalog/v1alpha1/generated.proto\x1a\"k8s.io/api/core/v1/generated.proto\x1a\x34k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x1a/k8s.io/apimachinery/pkg/runtime/generated.proto\x1a\x36k8s.io/apimachinery/pkg/runtime/schema/generated.proto\"W\n\x0c\x42\x61rChartSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\t\x12\t\n\x01y\x18\x03 \x01(\t\x12\x0e\n\x06legend\x18\x04 \x01(\x08\x12\x0c\n\x04sort\x18\x05 \x01(\x08\"\xa0\x07\n\x06\x43olumn\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64isplayName\x18\x02 \x01(\t\x12\x10\n\x08\x64\x61tatype\x18\x03 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0e\n\x06ignore\x18\x06 \x01(\x08\x12\x0e\n\x06target\x18\x07 \x01(\x08\x12\x10\n\x08nullable\x18\x08 \x01(\x08\x12\n\n\x02pk\x18\t \x01(\x08\x12\n\n\x02\x66k\x18\n \x01(\x08\x12\x12\n\nmultipleOf\x18\x0b \x01(\x05\x12\x0f\n\x07maximum\x18\x0c \x01(\x01\x12\x18\n\x10\x65xclusiveMaximum\x18\r \x01(\x08\x12\x0f\n\x07minimum\x18\x0e \x01(\x01\x12\x18\n\x10\x65xclusiveMinimum\x18\x0f \x01(\x08\x12\x11\n\tmaxLength\x18\x10 \x01(\x05\x12\x11\n\tminLength\x18\x11 \x01(\x05\x12\x0f\n\x07pattern\x18\x12 \x01(\t\x12\x10\n\x08required\x18\x13 \x01(\x08\x12\x0f\n\x07\x65xample\x18\x14 \x01(\t\x12\x14\n\x0c\x65xternalDocs\x18\x15 \x01(\t\x12\x0c\n\x04\x65num\x18\x16 \x03(\t\x12\x10\n\x08maxItems\x18\x18 \x01(\x05\x12\x10\n\x08minItems\x18\x19 \x01(\x05\x12\x13\n\x0buniqueItems\x18\x1a \x01(\x08\x12\x0b\n\x03pii\x18\x1c \x01(\x08\x12\x0b\n\x03phi\x18\x1d \x01(\x08\x12\x11\n\tprotected\x18\x1f \x01(\x08\x12\x17\n\x0f\x64\x65\x66\x61ultValueNum\x18  \x01(\x01\x12\x0b\n\x03log\x18! \x01(\x08\x12\n\n\x02mu\x18\" \x01(\x01\x12\r\n\x05sigma\x18# \x01(\x01\x12\x15\n\rskewThreshold\x18$ \x01(\x01\x12\x16\n\x0e\x64riftThreshold\x18% \x01(\x01\x12\x0b\n\x03key\x18& \x01(\x08\x12\x0c\n\x04\x66old\x18\' \x01(\x08\x12\x0e\n\x06weight\x18( \x01(\x08\x12\x10\n\x08reserved\x18) \x01(\x08\x12\x12\n\nimputation\x18* \x01(\t\x12\x0f\n\x07scaling\x18+ \x01(\t\x12\x11\n\tgenerated\x18, \x01(\x08\x12\x0f\n\x07\x66ormula\x18- \x01(\t\x12\n\n\x02id\x18. \x01(\x08\x12\x0c\n\x04step\x18/ \x01(\x01\x12\x0b\n\x03loc\x18\x30 \x01(\x05\x12\x16\n\x0e\x64\x61tetimeFormat\x18\x31 \x01(\t\x12\x12\n\ntimeseries\x18\x32 \x01(\x08\x12\x11\n\tregressor\x18\x33 \x01(\x08\x12\x17\n\x0flaggedRegressor\x18\x34 \x01(\x08\x12\x11\n\ttimeIndex\x18\x35 \x01(\x08\x12\x0c\n\x04\x61ggr\x18\x36 \x01(\t\x12\x0e\n\x06window\x18\x37 \x01(\x05\"\xe0\x01\n\x0f\x43olumnHistogram\x12\x0c\n\x04name\x18\x01 \x01(\t\x12Y\n\thistogram\x18\x02 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.HistogramData\x12U\n\x07metrics\x18\x03 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Measurement\x12\r\n\x05\x64rift\x18\x04 \x01(\x08\"\x81\x01\n\nColumnSpec\x12\x0e\n\x06spacer\x18\x01 \x01(\x08\x12\r\n\x05width\x18\x02 \x01(\x05\x12T\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ComponentSpec\"\xae\x07\n\x10\x43olumnStatistics\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tatype\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x01\x12\x10\n\x08\x64istinct\x18\x04 \x01(\x05\x12\x0f\n\x07missing\x18\x05 \x01(\x05\x12\x16\n\x0epercentMissing\x18\x06 \x01(\x01\x12\x0c\n\x04mean\x18\x07 \x01(\x01\x12\x0e\n\x06stddev\x18\x08 \x01(\x01\x12\x10\n\x08variance\x18\t \x01(\x01\x12\x0b\n\x03min\x18\n \x01(\x01\x12\x0b\n\x03max\x18\x0b \x01(\x01\x12\x10\n\x08kurtosis\x18\x0c \x01(\x01\x12\x10\n\x08skewness\x18\r \x01(\x01\x12\x0b\n\x03sum\x18\x0e \x01(\x01\x12\x0b\n\x03mad\x18\x0f \x01(\x01\x12\x0b\n\x03p25\x18\x10 \x01(\x01\x12\x0b\n\x03p50\x18\x11 \x01(\x01\x12\x0b\n\x03p75\x18\x12 \x01(\x01\x12\x0b\n\x03iqr\x18\x13 \x01(\x01\x12\x0c\n\x04mode\x18\x14 \x01(\t\x12\r\n\x05zeros\x18\x15 \x01(\x01\x12\x0f\n\x07invalid\x18\x16 \x01(\x05\x12\x12\n\nimportance\x18\x17 \x01(\x01\x12\x0e\n\x06target\x18\x18 \x01(\x08\x12\x0e\n\x06ignore\x18\x19 \x01(\x08\x12\x10\n\x08nullable\x18\x1a \x01(\x08\x12\x17\n\x0fhighCardinality\x18\x1b \x01(\x08\x12!\n\x19highCorrWithOtherFeatures\x18\x1c \x01(\x08\x12\x19\n\x11lowCorrWithTarget\x18\x1d \x01(\x08\x12\x16\n\x0ehighMissingPct\x18\x1e \x01(\x08\x12\x0e\n\x06skewed\x18\x1f \x01(\x08\x12\n\n\x02id\x18  \x01(\x08\x12\x10\n\x08\x63onstant\x18! \x01(\x08\x12\x11\n\tduplicate\x18\" \x01(\x08\x12\x10\n\x08reserved\x18# \x01(\x08\x12\x14\n\x0c\x63ompleteness\x18% \x01(\x01\x12\x1a\n\x12\x64istinctValueCount\x18& \x01(\x01\x12\x1b\n\x13mostFreqValuesRatio\x18\' \x01(\x01\x12\x1a\n\x12indexOfPeculiarity\x18( \x01(\x01\x12Y\n\thistogram\x18) \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.HistogramData\x12\x14\n\x0c\x63orrToTarget\x18* \x01(\x01\x12\r\n\x05index\x18+ \x01(\x05\x12S\n\x08outliers\x18, \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.OutlierStat\"\x96\x01\n\rComponentSpec\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x0e\n\x06\x66ooter\x18\x03 \x01(\t\x12T\n\x07\x63ontent\x18\x04 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ComponentView\"\xe3\x04\n\rComponentView\x12P\n\x06metric\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.MetricSpec\x12N\n\x05gauge\x18\x02 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GaugeSpec\x12V\n\thistogram\x18\x03 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.HistogramSpec\x12N\n\x05table\x18\x04 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.TableSpec\x12V\n\tlineChart\x18\x05 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LineChartSpec\x12T\n\x08\x62\x61rChart\x18\x06 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.BarChartSpec\x12Z\n\x0bscatterPlot\x18\x07 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ScatterPlotSpec\"P\n\x0b\x43orrelation\x12\x10\n\x08\x66\x65\x61ture1\x18\x01 \x01(\t\x12\x10\n\x08\x66\x65\x61ture2\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x01\x12\x0e\n\x06method\x18\x04 \x01(\t\">\n\x0f\x43orrelationSpec\x12\x0e\n\x06\x63utoff\x18\x01 \x01(\x01\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x0b\n\x03top\x18\x03 \x01(\x05\"\x8b\x02\n\x0b\x43svFileSpec\x12\x17\n\x0f\x63olumnDelimiter\x18\x01 \x01(\t\x12\x14\n\x0crowDelimiter\x18\x02 \x01(\t\x12\r\n\x05quote\x18\x03 \x01(\t\x12\x12\n\nescapeChar\x18\x04 \x01(\t\x12\x14\n\x0c\x63ommentChars\x18\x05 \x01(\t\x12\x0e\n\x06header\x18\x06 \x01(\x08\x12\x10\n\x08skipRows\x18\x07 \x01(\x05\x12\x12\n\nnullValues\x18\x08 \x01(\t\x12\x10\n\x08\x65ncoding\x18\t \x01(\t\x12\x0f\n\x07maxRows\x18\n \x01(\x05\x12\x0e\n\x06strict\x18\x0b \x01(\x08\x12\x13\n\x0b\x63ompression\x18\x0c \x01(\t\x12\x16\n\x0ehasIndexColumn\x18\r \x01(\x08\"\x88\x01\n\rDataInputSpec\x12\x0e\n\x06preSQL\x18\x01 \x03(\t\x12W\n\x0bobservation\x18\x02 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\"\xda\x01\n\x0c\x44\x61taLocation\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x16\n\x0e\x63onnectionName\x18\x02 \x01(\t\x12\x12\n\nbucketName\x18\x03 \x01(\t\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\r\n\x05table\x18\x05 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x06 \x01(\t\x12\x0b\n\x03sql\x18\x07 \x01(\t\x12\r\n\x05topic\x18\x08 \x01(\t\x12\x0b\n\x03url\x18\t \x01(\t\x12\x38\n\x0bresourceRef\x18\n \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\x89\x02\n\x0e\x44\x61taOutputSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12T\n\x08location\x18\x02 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\t\x12\x1d\n\x15\x63reateTableIfNotExist\x18\x05 \x01(\x08\x12\x17\n\x0fincludeFeatures\x18\x06 \x01(\x08\x12\x0b\n\x03xai\x18\x07 \x01(\x08\x12\x16\n\x0e\x64\x65tectOutliers\x18\x08 \x01(\x08\x12\x0f\n\x07postSQL\x18\t \x03(\t\"\x82\x02\n\x0c\x44\x61taPipeline\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12T\n\x04spec\x18\x02 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineSpec\x12X\n\x06status\x18\x03 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineStatus\"\xa7\x01\n\x10\x44\x61taPipelineList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12Q\n\x05items\x18\x02 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"\x8b\x02\n\x0f\x44\x61taPipelineRun\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12W\n\x04spec\x18\x02 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunSpec\x12[\n\x06status\x18\x03 \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunStatus\"\xa1\x01\n\x18\x44\x61taPipelineRunCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\xad\x01\n\x13\x44\x61taPipelineRunList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12T\n\x05items\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\xc8\x02\n\x13\x44\x61taPipelineRunSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x18\n\x10\x64\x61tapipelineName\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x04 \x01(\t\x12X\n\tresources\x18\x05 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x10\n\x08priority\x18\x06 \x01(\t\x12\x0e\n\x06paused\x18\x07 \x01(\x08\x12\x0f\n\x07\x61\x62orted\x18\x08 \x01(\x08\x12\x33\n\x06labRef\x18\t \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x16\n\x0emodelClassName\x18\n \x01(\t\x12\x19\n\x11modelClassRunName\x18\x0b \x01(\t\"\xfd\x03\n\x15\x44\x61taPipelineRunStatus\x12\x12\n\nrecipeRuns\x18\x01 \x03(\t\x12R\n\x06output\x18\x02 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\r\n\x05phase\x18\x03 \x01(\t\x12?\n\x0b\x63ompletedAt\x18\x05 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x1a\n\x12observedGeneration\x18\x06 \x01(\x03\x12\x15\n\rfailureReason\x18\x07 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x08 \x01(\t\x12\x10\n\x08progress\x18\t \x01(\x05\x12K\n\x04logs\x18\n \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12=\n\tupdatedAt\x18\x0b \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x43\n\nconditions\x18\x0c \x03(\x0b\x32/.k8s.io.apimachinery.pkg.apis.meta.v1.Condition\"\x80\x06\n\x10\x44\x61taPipelineSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x16\n\x0emodelClassName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12t\n\x0f\x64\x61tasetSelector\x18\x04 \x03(\x0b\x32[.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineSpec.DatasetSelectorEntry\x12U\n\x07recipes\x18\x05 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipePartSpec\x12T\n\x06output\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataOutputSpec\x12V\n\x08schedule\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunSchedule\x12_\n\x0cnotification\x18\x08 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.NotificationSpec\x12\r\n\x05owner\x18\t \x01(\t\x12X\n\tresources\x18\n \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x10\n\x08priority\x18\x0b \x01(\t\x12\x0e\n\x06paused\x18\x0c \x01(\x08\x12\x0b\n\x03ttl\x18\r \x01(\x05\x1a\x36\n\x14\x44\x61tasetSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xba\x02\n\x12\x44\x61taPipelineStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12=\n\tupdatedAt\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\\\n\x08schedule\x18\x03 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunScheduleStatus\x12\x13\n\x0blastRunName\x18\x04 \x01(\t\x12\x11\n\trunsCount\x18\x05 \x01(\x05\x12\x43\n\nconditions\x18\x06 \x03(\x0b\x32/.k8s.io.apimachinery.pkg.apis.meta.v1.Condition\"\xff\x01\n\x0b\x44\x61taProduct\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12S\n\x04spec\x18\x02 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductSpec\x12W\n\x06status\x18\x03 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductStatus\"\xa5\x01\n\x0f\x44\x61taProductList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12P\n\x05items\x18\x02 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"\xce\t\n\x0f\x44\x61taProductSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0e\n\x06public\x18\x02 \x01(\x08\x12\x36\n\ttenantRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12V\n\x0bgitLocation\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GitLocation\x12Z\n\rimageLocation\x18\x05 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ImageLocation\x12\x0f\n\x07labName\x18\x07 \x01(\t\x12\x17\n\x0fservingSiteName\x18\x08 \x01(\t\x12\x0c\n\x04task\x18\t \x01(\t\x12\x0f\n\x07subtask\x18\n \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0b \x01(\t\x12T\n\x08location\x18\x0c \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12_\n\x0cnotification\x18\r \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.NotificationSpec\x12`\n\x11trainingResources\x18\x0e \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12_\n\x10servingResources\x18\x0f \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x18\n\x10retriesOnFailure\x18\x10 \x01(\x05\x12G\n\x04kpis\x18\x11 \x03(\x0b\x32\x39.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.KPI\x12\x19\n\x11onCallAccountName\x18\x12 \x01(\t\x12Z\n\x0b\x63ompilation\x18\x13 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CompilerSpec\x12\x16\n\x0e\x63learanceLevel\x18\x14 \x01(\t\x12\x10\n\x08priority\x18\x15 \x01(\t\x12\r\n\x05\x63olor\x18\x16 \x01(\t\x12X\n\ngovernance\x18\x17 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceSpec\x12]\n\x0bpermissions\x18\x18 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PermissionsSpec\x12\x0c\n\x04tags\x18\x19 \x03(\t\"\xa9\x04\n\x11\x44\x61taProductStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12=\n\tupdatedAt\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x18\n\x10\x64\x61tasourcesCount\x18\x03 \x01(\x05\x12\x15\n\rdatasetsCount\x18\x04 \x01(\x05\x12\x19\n\x11\x64\x61taPipelineCount\x18\x05 \x01(\x05\x12\x1d\n\x15totalDataPipelineRuns\x18\x06 \x01(\x05\x12\x14\n\x0cstudiesCount\x18\x07 \x01(\x05\x12\x13\n\x0bmodelsCount\x18\x08 \x01(\x05\x12\x17\n\x0fpredictorsCount\x18\x0b \x01(\x05\x12\x15\n\rdataAppsCount\x18\r \x01(\x05\x12\x18\n\x10predictionsCount\x18\x0e \x01(\x05\x12\x17\n\x0finfoAlertsCount\x18\x0f \x01(\x05\x12\x18\n\x10\x65rrorAlertsCount\x18\x10 \x01(\x05\x12\x19\n\x11modelClassesCount\x18\x11 \x01(\x05\x12\x15\n\rfailureReason\x18\x12 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x13 \x01(\t\x12\x17\n\x0f\x62\x61selineVersion\x18\x14 \x01(\t\x12\x43\n\nconditions\x18\x15 \x03(\x0b\x32/.k8s.io.apimachinery.pkg.apis.meta.v1.Condition\"\x94\x02\n\x12\x44\x61taProductVersion\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12Z\n\x04spec\x18\x02 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersionSpec\x12^\n\x06status\x18\x03 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersionStatus\"\xb3\x01\n\x16\x44\x61taProductVersionList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12W\n\x05items\x18\x02 \x03(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"\xa0\x01\n\x16\x44\x61taProductVersionSpec\x12\x37\n\nproductRef\x18\x01 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0fprevVersionName\x18\x03 \x01(\t\x12\x10\n\x08\x62\x61seline\x18\x04 \x01(\x08\x12\r\n\x05owner\x18\x05 \x01(\t\"\xe9\x01\n\x18\x44\x61taProductVersionStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12=\n\tupdatedAt\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x03 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x04 \x01(\t\x12\x43\n\nconditions\x18\x05 \x03(\x0b\x32/.k8s.io.apimachinery.pkg.apis.meta.v1.Condition\"\xfc\x01\n\nDataSource\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12R\n\x04spec\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceSpec\x12V\n\x06status\x18\x03 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceStatus\"\xa3\x01\n\x0e\x44\x61taSourceList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12O\n\x05items\x18\x02 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"\x8e\x06\n\x0e\x44\x61taSourceSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x61tasetType\x18\x04 \x01(\t\x12L\n\x06schema\x18\x05 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Schema\x12Z\n\x08\x66latfile\x18\x06 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FlatFileFormatSpec\x12\x0f\n\x07labeled\x18\x07 \x01(\x08\x12P\n\x06sample\x18\t \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SampleSpec\x12\x0c\n\x04task\x18\n \x01(\t\x12\x0f\n\x07subtask\x18\x0b \x01(\t\x12]\n\rrelationships\x18\x0c \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RelationshipSpec\x12T\n\x08labeling\x18\r \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingSpec\x12X\n\x0cinferredFrom\x18\x0e \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12]\n\x11unitTestsTemplate\x18\x0f \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.TestSuite\x12\x14\n\x0cingestMethod\x18\x10 \x01(\t\"\xd2\x02\n\x10\x44\x61taSourceStatus\x12\x0c\n\x04\x63ols\x18\x01 \x01(\x05\x12\x1a\n\x12observedGeneration\x18\x02 \x01(\x03\x12H\n\x14lastDatasetCreatedAt\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x17\n\x0flastDatasetName\x18\x04 \x01(\t\x12=\n\tupdatedAt\x18\x05 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x06 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x07 \x01(\t\x12\x43\n\nconditions\x18\x08 \x03(\x0b\x32/.k8s.io.apimachinery.pkg.apis.meta.v1.Condition\"\xf3\x01\n\x07\x44\x61taset\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12O\n\x04spec\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetSpec\x12S\n\x06status\x18\x03 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetStatus\"\xe0\x01\n\x14\x44\x61tasetGroupByStatus\x12\x13\n\x0b\x64\x61tasetsURI\x18\x01 \x01(\t\x12\x13\n\x0bprofilesURI\x18\x02 \x01(\t\x12\x12\n\nreportsURI\x18\x03 \x01(\t\x12\x14\n\x0cunitTestsURI\x18\x04 \x01(\t\x12\x13\n\x0b\x66\x65\x61turesURI\x18\x05 \x01(\t\x12_\n\rworkerResults\x18\x06 \x03(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.WorkerRunResult\"\x9d\x01\n\x0b\x44\x61tasetList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12L\n\x05items\x18\x02 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\xb4\x0c\n\x0b\x44\x61tasetSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x61tasourceName\x18\x03 \x01(\t\x12\x18\n\x10\x66\x65\x61tureGroupName\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x13\n\x0b\x64isplayName\x18\x08 \x01(\t\x12\x0c\n\x04role\x18\t \x01(\t\x12\x0c\n\x04tags\x18\n \x03(\t\x12\x10\n\x08reported\x18\x0b \x01(\x08\x12\x13\n\x0bsnapshotted\x18\x0c \x01(\x08\x12\x12\n\nunitTested\x18\r \x01(\x08\x12R\n\x06origin\x18\x0e \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12T\n\x08location\x18\x0f \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12X\n\tresources\x18\x10 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x0f\n\x07timeout\x18\x11 \x01(\x03\x12\x0c\n\x04type\x18\x12 \x01(\t\x12P\n\x06sample\x18\x13 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SampleSpec\x12V\n\tsynthetic\x18\x14 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SyntheticSpec\x12\x0c\n\x04task\x18\x15 \x01(\t\x12\x0f\n\x07subtask\x18\x16 \x01(\t\x12Z\n\x0b\x63orrelation\x18\x17 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.CorrelationSpec\x12\x0c\n\x04\x66\x61st\x18\x18 \x01(\x08\x12\x12\n\nfeaturized\x18\x19 \x01(\x08\x12\x33\n\x06labRef\x18\x1a \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12>\n\x11servingDatasetRef\x18\x1b \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x39\n\x0cpredictorRef\x18\x1c \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12 \n\x18generateFeatureHistogram\x18\x1d \x01(\x08\x12U\n\tunitTests\x18\x1e \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.TestSuite\x12R\n\x07groupBy\x18\x1f \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GroupBySpec\x12g\n\x0egroupLocations\x18  \x01(\x0b\x32O.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GroupDatasetLocationsSpec\x12\x0b\n\x03key\x18! \x03(\t\x12@\n\x0cminEventTime\x18\" \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12@\n\x0cmaxEventTime\x18# \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x16\n\x0emodelClassName\x18$ \x01(\t\x12\x19\n\x11modelClassRunName\x18% \x01(\t\x12:\n\rfeatureGroups\x18& \x03(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xd9\x02\n\x11\x44\x61tasetStatistics\x12W\n\x07\x63olumns\x18\x01 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnStatistics\x12\x0c\n\x04rows\x18\x03 \x01(\x05\x12\x0c\n\x04\x63ols\x18\x04 \x01(\x05\x12\x10\n\x08\x66ileSize\x18\x05 \x01(\x05\x12\x61\n\x16\x63orrelationsWithTarget\x18\x06 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Correlation\x12Z\n\x0ftopCorrelations\x18\x07 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Correlation\"\x89\x08\n\rDatasetStatus\x12[\n\nstatistics\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetStatistics\x12\r\n\x05phase\x18\x02 \x01(\t\x12\x12\n\nreportName\x18\x03 \x01(\t\x12\x11\n\treportURI\x18\x04 \x01(\t\x12\x12\n\nprofileURI\x18\x05 \x01(\t\x12\x12\n\nimbalanced\x18\x06 \x01(\x08\x12\x14\n\x0c\x61nomaliesURI\x18\x07 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x08 \x01(\x03\x12]\n\x0btestResults\x18\t \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.TestSuiteResult\x12?\n\x0blastStudyAt\x18\n \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x15\n\rfailureReason\x18\x0c \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\r \x01(\t\x12\x10\n\x08progress\x18\x0e \x01(\x05\x12\x0c\n\x04hash\x18\x0f \x01(\t\x12K\n\x04logs\x18\x10 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12\x1a\n\x12\x64\x65rivedFromDataset\x18\x11 \x01(\t\x12=\n\tupdatedAt\x18\x12 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12O\n\x06images\x18\x13 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Images\x12?\n\x0b\x63ompletedAt\x18\x15 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12@\n\x13\x66\x65\x61tureHistogramRef\x18\x16 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12[\n\x07groupby\x18\x17 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetGroupByStatus\x12\x43\n\nconditions\x18\x18 \x03(\x0b\x32/.k8s.io.apimachinery.pkg.apis.meta.v1.Condition\"\xa6\x01\n\x0f\x44\x61tasetTemplate\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12O\n\x04spec\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetSpec\"/\n\x0e\x44riftThreshold\x12\x0e\n\x06metric\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\"\xf0\x01\n\x06\x45ntity\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12N\n\x04spec\x18\x02 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntitySpec\x12R\n\x06status\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntityStatus\"\x98\x01\n\x0f\x45ntityCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x9b\x01\n\nEntityList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12K\n\x05items\x18\x02 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"\x98\x01\n\nEntitySpec\x12\x36\n\ttenantRef\x18\x01 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07joinKey\x18\x04 \x01(\t\x12\r\n\x05owner\x18\x05 \x01(\t\x12\x0c\n\x04tags\x18\x06 \x03(\t\"\xae\x01\n\x0c\x45ntityStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12=\n\tupdatedAt\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x43\n\nconditions\x18\x03 \x03(\x0b\x32/.k8s.io.apimachinery.pkg.apis.meta.v1.Condition\"\xc1\x01\n\x11\x45xcelNotebookSpec\x12\x1a\n\x12\x66irstSheetWithData\x18\x01 \x01(\x08\x12\x11\n\tsheetName\x18\x02 \x01(\t\x12\x12\n\nsheetIndex\x18\x03 \x01(\x05\x12\x15\n\rcolumnNameRow\x18\x04 \x01(\x05\x12R\n\x04\x64\x61ta\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ExcelSheetArea\"k\n\x0e\x45xcelSheetArea\x12\x13\n\x0b\x65ntireSheet\x18\x01 \x01(\x08\x12\x12\n\nfromColumn\x18\x02 \x01(\x05\x12\x10\n\x08toColumn\x18\x03 \x01(\x05\x12\x0f\n\x07\x66romRow\x18\x04 \x01(\x05\x12\r\n\x05toRow\x18\x05 \x01(\x05\"\x82\x02\n\x0c\x46\x65\x61tureGroup\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12T\n\x04spec\x18\x02 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroupSpec\x12X\n\x06status\x18\x03 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroupStatus\"\xa7\x01\n\x10\x46\x65\x61tureGroupList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12Q\n\x05items\x18\x02 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\"\xc1\x07\n\x10\x46\x65\x61tureGroupSpec\x12\x36\n\ttenantRef\x18\x01 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x12\n\ningestType\x18\x05 \x01(\t\x12\x12\n\nentityName\x18\x06 \x01(\t\x12\x0c\n\x04tags\x18\x07 \x03(\t\x12\\\n\x0eingestSchedule\x18\x08 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunSchedule\x12Z\n\x0csyncSchedule\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunSchedule\x12Z\n\x08\x66latfile\x18\n \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FlatFileFormatSpec\x12L\n\x06schema\x18\x0b \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Schema\x12Q\n\x05tests\x18\x0c \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.TestSuite\x12T\n\x08location\x18\r \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\x12\n\ntimeColumn\x18\x0e \x01(\t\x12\x18\n\x10timeColumnFormat\x18\x0f \x01(\t\x12\x11\n\tkeyColumn\x18\x10 \x01(\t\x12\x62\n\x0fmaterialization\x18\x11 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.MaterializationSpec\x12X\n\tresources\x18\x12 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\"\x84\x05\n\x12\x46\x65\x61tureGroupStatus\x12\r\n\x05phase\x18\x02 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x03 \x01(\x03\x12=\n\tupdatedAt\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0c\n\x04rows\x18\x05 \x01(\x05\x12\x62\n\x0eingestSchedule\x18\x07 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunScheduleStatus\x12`\n\x0csyncSchedule\x18\x08 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunScheduleStatus\x12X\n\x0conelineTable\x18\t \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12G\n\x13onelineTableCreated\x18\n \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x19\n\x11ingestDatasetName\x18\x0b \x01(\t\x12\x15\n\rfailureReason\x18\x0c \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\r \x01(\t\x12\x43\n\nconditions\x18\x0e \x03(\x0b\x32/.k8s.io.apimachinery.pkg.apis.meta.v1.Condition\"\x8e\x02\n\x10\x46\x65\x61tureHistogram\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12X\n\x04spec\x18\x02 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramSpec\x12\\\n\x06status\x18\x03 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramStatus\"\xaf\x01\n\x14\x46\x65\x61tureHistogramList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12U\n\x05items\x18\x02 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\"\xf5\x04\n\x14\x46\x65\x61tureHistogramSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x05 \x03(\t\x12\x36\n\tsourceRef\x18\x06 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x10\n\x08training\x18\x07 \x01(\x08\x12\x0c\n\x04live\x18\t \x01(\x08\x12\x39\n\x05start\x18\n \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x37\n\x03\x65nd\x18\x0b \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x34\n\x07\x62\x61seRef\x18\x0c \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12]\n\x0f\x64riftThresholds\x18\r \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DriftThreshold\x12\x17\n\x0fsyncIntervalSec\x18\x0e \x01(\x05\x12U\n\tunitTests\x18\x0f \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.TestSuite\x12\x14\n\x0cgenUnitTests\x18\x10 \x01(\x08\x12\x15\n\rfeatureFilter\x18\x11 \x01(\t\x12\x15\n\rreferenceType\x18\x12 \x01(\t\"\x9d\x04\n\x16\x46\x65\x61tureHistogramStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12V\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnHistogram\x12=\n\tupdatedAt\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12K\n\x04logs\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12\r\n\x05phase\x18\x06 \x01(\t\x12\x15\n\rfailureReason\x18\x07 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x08 \x01(\t\x12\x61\n\x0funitTestsResult\x18\t \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.TestSuiteResult\x12\r\n\x05total\x18\n \x01(\x05\x12\x0e\n\x06\x65rrors\x18\x0b \x01(\x05\x12\x43\n\nconditions\x18\x0c \x03(\x0b\x32/.k8s.io.apimachinery.pkg.apis.meta.v1.Condition\"\xa6\x02\n\x12\x46latFileFormatSpec\x12\x10\n\x08\x66ileType\x18\x01 \x01(\t\x12N\n\x03\x63sv\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.CsvFileSpec\x12V\n\x05\x65xcel\x18\x03 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ExcelNotebookSpec\x12V\n\x07parquet\x18\x04 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ParquetFileSpec\"M\n\tGaugeSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\t\x12\x0b\n\x03row\x18\x03 \x01(\x05\x12\x0e\n\x06scalar\x18\x04 \x01(\t\"V\n\x0bGitLocation\x12\x19\n\x11gitConnectionName\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\t\x12\x0f\n\x07private\x18\x04 \x01(\x08\"w\n\x16GovernanceReviewStatus\x12\x0e\n\x06result\x18\x01 \x01(\t\x12>\n\napprovedAt\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\r\n\x05notes\x18\x03 \x01(\t\"\x8d\x01\n\x0eGovernanceSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x12\n\nitReviewer\x18\x03 \x01(\t\x12\x1a\n\x12\x63omplianceReviewer\x18\x04 \x01(\t\x12\x18\n\x10\x62usinessReviewer\x18\x05 \x01(\t\x12\x0f\n\x07members\x18\x06 \x03(\t\"\xd2\x02\n\x10GovernanceStatus\x12\x64\n\x0eITReviewStatus\x18\x01 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceReviewStatus\x12l\n\x16\x63omplianceReviewStatus\x18\x02 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceReviewStatus\x12j\n\x14\x62usinessReviewStatus\x18\x03 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceReviewStatus\"]\n\x0bGroupBySpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07groupby\x18\x02 \x03(\t\x12\x0c\n\x04\x66req\x18\x03 \x01(\t\x12\x10\n\x08interval\x18\x04 \x01(\x05\x12\x0c\n\x04\x61ggr\x18\x05 \x01(\t\"\xc2\x01\n\x19GroupDatasetLocationsSpec\x12\x12\n\ngroupsRoot\x18\x01 \x01(\t\x12\x11\n\tgroupRoot\x18\x02 \x01(\t\x12\x17\n\x0fgroupDataFolder\x18\x03 \x01(\t\x12\x15\n\rgroupDataFile\x18\x04 \x01(\t\x12\x1a\n\x12groupProfileFolder\x18\x05 \x01(\t\x12\x17\n\x0fgroupReportFile\x18\x06 \x01(\t\x12\x19\n\x11groupFeaturesFile\x18\x07 \x01(\t\"=\n\rHistogramSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\t\x12\x0c\n\x04\x62ins\x18\x03 \x01(\x05\"=\n\rImageLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1e\n\x16registryConnectionName\x18\x02 \x01(\t\"\"\n\x03KPI\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\"?\n\x0cLabelingRule\x12\x0e\n\x06\x63olumn\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xe1\x01\n\x0cLabelingSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x14\n\x0cresultColumn\x18\x02 \x01(\t\x12T\n\x08positive\x18\x03 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingRule\x12T\n\x08negative\x18\x04 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingRule\"J\n\rLineChartSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\t\x12\t\n\x01y\x18\x03 \x01(\t\x12\x0e\n\x06legend\x18\x04 \x01(\x08\"\x86\x02\n\x13MaterializationSpec\x12\x0e\n\x06online\x18\x01 \x01(\x08\x12\x0f\n\x07offline\x18\x02 \x01(\x08\x12=\n\tstartDate\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x12\n\nofflineTTL\x18\x04 \x01(\x05\x12\x11\n\tonlineTTL\x18\x05 \x01(\x05\x12\x10\n\x08\x62\x61\x63kfill\x18\x06 \x01(\x05\x12V\n\x08schedule\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.RunSchedule\"N\n\nMetricSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\t\x12\x0b\n\x03row\x18\x03 \x01(\x05\x12\x0e\n\x06scalar\x18\x04 \x01(\t\"<\n\x0bOutlierStat\x12\r\n\x05lower\x18\x01 \x01(\x05\x12\r\n\x05upper\x18\x02 \x01(\x05\x12\x0f\n\x07percent\x18\x03 \x01(\x02\"W\n\x08PageSpec\x12K\n\x04rows\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RowSpec\"!\n\x0fParquetFileSpec\x12\x0e\n\x06\x65ngine\x18\x01 \x01(\t\"\xf0\x01\n\x06Recipe\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12N\n\x04spec\x18\x02 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeSpec\x12R\n\x06status\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeStatus\"\x8c\x01\n\x0fRecipeInputSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12T\n\x08location\x18\x02 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\"\x9b\x01\n\nRecipeList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12K\n\x05items\x18\x02 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x94\x01\n\x10RecipeOutputSpec\x12\x15\n\rcreateDataset\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x61tasetName\x18\x02 \x01(\t\x12T\n\x08location\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\"8\n\x0eRecipePartSpec\x12\x12\n\nrecipeName\x18\x01 \x01(\t\x12\x12\n\ndependents\x18\x02 \x03(\t\"\xf9\x01\n\tRecipeRun\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12Q\n\x04spec\x18\x02 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRunSpec\x12U\n\x06status\x18\x03 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRunStatus\"\xa1\x01\n\rRecipeRunList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12N\n\x05items\x18\x02 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\xdd\x02\n\rRecipeRunSpec\x12\x13\n\x0bversionName\x18\x01 \x01(\t\x12\x12\n\nrecipeName\x18\x02 \x01(\t\x12\x33\n\x06labRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12T\n\x08location\x18\x04 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12X\n\tresources\x18\x05 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x0b\n\x03ttl\x18\x06 \x01(\x05\x12\x16\n\x0emodelClassName\x18\x07 \x01(\t\x12\x19\n\x11modelClassRunName\x18\x08 \x01(\t\"\x92\x03\n\x0fRecipeRunStatus\x12?\n\x0b\x63ompletedAt\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\r\n\x05phase\x18\x02 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x03 \x01(\x03\x12\x15\n\rfailureReason\x18\x04 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x05 \x01(\t\x12\x13\n\x0btriggeredBy\x18\x06 \x01(\t\x12K\n\x04logs\x18\x07 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Logs\x12=\n\tupdatedAt\x18\t \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x43\n\nconditions\x18\x0b \x03(\x0b\x32/.k8s.io.apimachinery.pkg.apis.meta.v1.Condition\"\xed\x04\n\nRecipeSpec\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0bversionName\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12T\n\x05input\x18\x04 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeInputSpec\x12O\n\x05steps\x18\x05 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeStep\x12V\n\x06output\x18\x06 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeOutputSpec\x12P\n\x06sample\x18\x07 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SampleSpec\x12X\n\tresources\x18\x08 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ResourceSpec\x12\x0f\n\x07timeout\x18\n \x01(\x03\x12\x0b\n\x03ttl\x18\x0b \x01(\x05\x12]\n\x11unitTestsTemplate\x18\x0c \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.TestSuite\"\x87\x02\n\x0cRecipeStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12W\n\x07lastRun\x18\x02 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.LastRunStatus\x12=\n\tupdatedAt\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x43\n\nconditions\x18\x07 \x03(\x0b\x32/.k8s.io.apimachinery.pkg.apis.meta.v1.Condition\"s\n\nRecipeStep\x12\n\n\x02op\x18\x01 \x01(\t\x12Y\n\nparameters\x18\x02 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeStepParam\".\n\x0fRecipeStepParam\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"X\n\x14RecommendationSchema\x12\x14\n\x0cuserIDColumn\x18\x01 \x01(\t\x12\x14\n\x0citemIDColumn\x18\x02 \x01(\t\x12\x14\n\x0cratingColumn\x18\x03 \x01(\t\"R\n\x10RelationshipSpec\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\t\x12\r\n\x05\x61rity\x18\x03 \x01(\t\x12\x11\n\trelatesTo\x18\x04 \x01(\t\"Y\n\x07RowSpec\x12N\n\x04\x63ols\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnSpec\"j\n\nSampleSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04rows\x18\x03 \x01(\x05\x12\x0f\n\x07percent\x18\x04 \x01(\x05\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x06 \x01(\t\"<\n\x0fScatterPlotSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\t\x12\t\n\x01y\x18\x03 \x01(\t\"\xb0\x02\n\x06Schema\x12`\n\x10timeSeriesSchema\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.TimeSeriesSchema\x12h\n\x14recommendationSchema\x18\x02 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecommendationSchema\x12M\n\x07\x63olumns\x18\x03 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Column\x12\x0b\n\x03key\x18\x04 \x03(\t\".\n\rSyntheticSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0c\n\x04rows\x18\x02 \x01(\x05\"\x84\x01\n\tTableSpec\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x12\x0f\n\x07\x66ilters\x18\x03 \x03(\t\x12\x0f\n\x07groupby\x18\x04 \x03(\t\x12\x0c\n\x04rows\x18\x05 \x01(\x05\x12\x11\n\tshowIndex\x18\x06 \x01(\x08\x12\x0e\n\x06\x62order\x18\x07 \x01(\x08\"@\n\x10TimeSeriesSchema\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04\x66req\x18\x02 \x01(\t\x12\x10\n\x08interval\x18\x03 \x01(\x05\x42\x36Z4github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1')



_BARCHARTSPEC = DESCRIPTOR.message_types_by_name['BarChartSpec']
_COLUMN = DESCRIPTOR.message_types_by_name['Column']
_COLUMNHISTOGRAM = DESCRIPTOR.message_types_by_name['ColumnHistogram']
_COLUMNSPEC = DESCRIPTOR.message_types_by_name['ColumnSpec']
_COLUMNSTATISTICS = DESCRIPTOR.message_types_by_name['ColumnStatistics']
_COMPONENTSPEC = DESCRIPTOR.message_types_by_name['ComponentSpec']
_COMPONENTVIEW = DESCRIPTOR.message_types_by_name['ComponentView']
_CORRELATION = DESCRIPTOR.message_types_by_name['Correlation']
_CORRELATIONSPEC = DESCRIPTOR.message_types_by_name['CorrelationSpec']
_CSVFILESPEC = DESCRIPTOR.message_types_by_name['CsvFileSpec']
_DATAINPUTSPEC = DESCRIPTOR.message_types_by_name['DataInputSpec']
_DATALOCATION = DESCRIPTOR.message_types_by_name['DataLocation']
_DATAOUTPUTSPEC = DESCRIPTOR.message_types_by_name['DataOutputSpec']
_DATAPIPELINE = DESCRIPTOR.message_types_by_name['DataPipeline']
_DATAPIPELINELIST = DESCRIPTOR.message_types_by_name['DataPipelineList']
_DATAPIPELINERUN = DESCRIPTOR.message_types_by_name['DataPipelineRun']
_DATAPIPELINERUNCONDITION = DESCRIPTOR.message_types_by_name['DataPipelineRunCondition']
_DATAPIPELINERUNLIST = DESCRIPTOR.message_types_by_name['DataPipelineRunList']
_DATAPIPELINERUNSPEC = DESCRIPTOR.message_types_by_name['DataPipelineRunSpec']
_DATAPIPELINERUNSTATUS = DESCRIPTOR.message_types_by_name['DataPipelineRunStatus']
_DATAPIPELINESPEC = DESCRIPTOR.message_types_by_name['DataPipelineSpec']
_DATAPIPELINESPEC_DATASETSELECTORENTRY = _DATAPIPELINESPEC.nested_types_by_name['DatasetSelectorEntry']
_DATAPIPELINESTATUS = DESCRIPTOR.message_types_by_name['DataPipelineStatus']
_DATAPRODUCT = DESCRIPTOR.message_types_by_name['DataProduct']
_DATAPRODUCTLIST = DESCRIPTOR.message_types_by_name['DataProductList']
_DATAPRODUCTSPEC = DESCRIPTOR.message_types_by_name['DataProductSpec']
_DATAPRODUCTSTATUS = DESCRIPTOR.message_types_by_name['DataProductStatus']
_DATAPRODUCTVERSION = DESCRIPTOR.message_types_by_name['DataProductVersion']
_DATAPRODUCTVERSIONLIST = DESCRIPTOR.message_types_by_name['DataProductVersionList']
_DATAPRODUCTVERSIONSPEC = DESCRIPTOR.message_types_by_name['DataProductVersionSpec']
_DATAPRODUCTVERSIONSTATUS = DESCRIPTOR.message_types_by_name['DataProductVersionStatus']
_DATASOURCE = DESCRIPTOR.message_types_by_name['DataSource']
_DATASOURCELIST = DESCRIPTOR.message_types_by_name['DataSourceList']
_DATASOURCESPEC = DESCRIPTOR.message_types_by_name['DataSourceSpec']
_DATASOURCESTATUS = DESCRIPTOR.message_types_by_name['DataSourceStatus']
_DATASET = DESCRIPTOR.message_types_by_name['Dataset']
_DATASETGROUPBYSTATUS = DESCRIPTOR.message_types_by_name['DatasetGroupByStatus']
_DATASETLIST = DESCRIPTOR.message_types_by_name['DatasetList']
_DATASETSPEC = DESCRIPTOR.message_types_by_name['DatasetSpec']
_DATASETSTATISTICS = DESCRIPTOR.message_types_by_name['DatasetStatistics']
_DATASETSTATUS = DESCRIPTOR.message_types_by_name['DatasetStatus']
_DATASETTEMPLATE = DESCRIPTOR.message_types_by_name['DatasetTemplate']
_DRIFTTHRESHOLD = DESCRIPTOR.message_types_by_name['DriftThreshold']
_ENTITY = DESCRIPTOR.message_types_by_name['Entity']
_ENTITYCONDITION = DESCRIPTOR.message_types_by_name['EntityCondition']
_ENTITYLIST = DESCRIPTOR.message_types_by_name['EntityList']
_ENTITYSPEC = DESCRIPTOR.message_types_by_name['EntitySpec']
_ENTITYSTATUS = DESCRIPTOR.message_types_by_name['EntityStatus']
_EXCELNOTEBOOKSPEC = DESCRIPTOR.message_types_by_name['ExcelNotebookSpec']
_EXCELSHEETAREA = DESCRIPTOR.message_types_by_name['ExcelSheetArea']
_FEATUREGROUP = DESCRIPTOR.message_types_by_name['FeatureGroup']
_FEATUREGROUPLIST = DESCRIPTOR.message_types_by_name['FeatureGroupList']
_FEATUREGROUPSPEC = DESCRIPTOR.message_types_by_name['FeatureGroupSpec']
_FEATUREGROUPSTATUS = DESCRIPTOR.message_types_by_name['FeatureGroupStatus']
_FEATUREHISTOGRAM = DESCRIPTOR.message_types_by_name['FeatureHistogram']
_FEATUREHISTOGRAMLIST = DESCRIPTOR.message_types_by_name['FeatureHistogramList']
_FEATUREHISTOGRAMSPEC = DESCRIPTOR.message_types_by_name['FeatureHistogramSpec']
_FEATUREHISTOGRAMSTATUS = DESCRIPTOR.message_types_by_name['FeatureHistogramStatus']
_FLATFILEFORMATSPEC = DESCRIPTOR.message_types_by_name['FlatFileFormatSpec']
_GAUGESPEC = DESCRIPTOR.message_types_by_name['GaugeSpec']
_GITLOCATION = DESCRIPTOR.message_types_by_name['GitLocation']
_GOVERNANCEREVIEWSTATUS = DESCRIPTOR.message_types_by_name['GovernanceReviewStatus']
_GOVERNANCESPEC = DESCRIPTOR.message_types_by_name['GovernanceSpec']
_GOVERNANCESTATUS = DESCRIPTOR.message_types_by_name['GovernanceStatus']
_GROUPBYSPEC = DESCRIPTOR.message_types_by_name['GroupBySpec']
_GROUPDATASETLOCATIONSSPEC = DESCRIPTOR.message_types_by_name['GroupDatasetLocationsSpec']
_HISTOGRAMSPEC = DESCRIPTOR.message_types_by_name['HistogramSpec']
_IMAGELOCATION = DESCRIPTOR.message_types_by_name['ImageLocation']
_KPI = DESCRIPTOR.message_types_by_name['KPI']
_LABELINGRULE = DESCRIPTOR.message_types_by_name['LabelingRule']
_LABELINGSPEC = DESCRIPTOR.message_types_by_name['LabelingSpec']
_LINECHARTSPEC = DESCRIPTOR.message_types_by_name['LineChartSpec']
_MATERIALIZATIONSPEC = DESCRIPTOR.message_types_by_name['MaterializationSpec']
_METRICSPEC = DESCRIPTOR.message_types_by_name['MetricSpec']
_OUTLIERSTAT = DESCRIPTOR.message_types_by_name['OutlierStat']
_PAGESPEC = DESCRIPTOR.message_types_by_name['PageSpec']
_PARQUETFILESPEC = DESCRIPTOR.message_types_by_name['ParquetFileSpec']
_RECIPE = DESCRIPTOR.message_types_by_name['Recipe']
_RECIPEINPUTSPEC = DESCRIPTOR.message_types_by_name['RecipeInputSpec']
_RECIPELIST = DESCRIPTOR.message_types_by_name['RecipeList']
_RECIPEOUTPUTSPEC = DESCRIPTOR.message_types_by_name['RecipeOutputSpec']
_RECIPEPARTSPEC = DESCRIPTOR.message_types_by_name['RecipePartSpec']
_RECIPERUN = DESCRIPTOR.message_types_by_name['RecipeRun']
_RECIPERUNLIST = DESCRIPTOR.message_types_by_name['RecipeRunList']
_RECIPERUNSPEC = DESCRIPTOR.message_types_by_name['RecipeRunSpec']
_RECIPERUNSTATUS = DESCRIPTOR.message_types_by_name['RecipeRunStatus']
_RECIPESPEC = DESCRIPTOR.message_types_by_name['RecipeSpec']
_RECIPESTATUS = DESCRIPTOR.message_types_by_name['RecipeStatus']
_RECIPESTEP = DESCRIPTOR.message_types_by_name['RecipeStep']
_RECIPESTEPPARAM = DESCRIPTOR.message_types_by_name['RecipeStepParam']
_RECOMMENDATIONSCHEMA = DESCRIPTOR.message_types_by_name['RecommendationSchema']
_RELATIONSHIPSPEC = DESCRIPTOR.message_types_by_name['RelationshipSpec']
_ROWSPEC = DESCRIPTOR.message_types_by_name['RowSpec']
_SAMPLESPEC = DESCRIPTOR.message_types_by_name['SampleSpec']
_SCATTERPLOTSPEC = DESCRIPTOR.message_types_by_name['ScatterPlotSpec']
_SCHEMA = DESCRIPTOR.message_types_by_name['Schema']
_SYNTHETICSPEC = DESCRIPTOR.message_types_by_name['SyntheticSpec']
_TABLESPEC = DESCRIPTOR.message_types_by_name['TableSpec']
_TIMESERIESSCHEMA = DESCRIPTOR.message_types_by_name['TimeSeriesSchema']
BarChartSpec = _reflection.GeneratedProtocolMessageType('BarChartSpec', (_message.Message,), {
  'DESCRIPTOR' : _BARCHARTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.BarChartSpec)
  })
_sym_db.RegisterMessage(BarChartSpec)

Column = _reflection.GeneratedProtocolMessageType('Column', (_message.Message,), {
  'DESCRIPTOR' : _COLUMN,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Column)
  })
_sym_db.RegisterMessage(Column)

ColumnHistogram = _reflection.GeneratedProtocolMessageType('ColumnHistogram', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNHISTOGRAM,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnHistogram)
  })
_sym_db.RegisterMessage(ColumnHistogram)

ColumnSpec = _reflection.GeneratedProtocolMessageType('ColumnSpec', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnSpec)
  })
_sym_db.RegisterMessage(ColumnSpec)

ColumnStatistics = _reflection.GeneratedProtocolMessageType('ColumnStatistics', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNSTATISTICS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ColumnStatistics)
  })
_sym_db.RegisterMessage(ColumnStatistics)

ComponentSpec = _reflection.GeneratedProtocolMessageType('ComponentSpec', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ComponentSpec)
  })
_sym_db.RegisterMessage(ComponentSpec)

ComponentView = _reflection.GeneratedProtocolMessageType('ComponentView', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTVIEW,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ComponentView)
  })
_sym_db.RegisterMessage(ComponentView)

Correlation = _reflection.GeneratedProtocolMessageType('Correlation', (_message.Message,), {
  'DESCRIPTOR' : _CORRELATION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Correlation)
  })
_sym_db.RegisterMessage(Correlation)

CorrelationSpec = _reflection.GeneratedProtocolMessageType('CorrelationSpec', (_message.Message,), {
  'DESCRIPTOR' : _CORRELATIONSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.CorrelationSpec)
  })
_sym_db.RegisterMessage(CorrelationSpec)

CsvFileSpec = _reflection.GeneratedProtocolMessageType('CsvFileSpec', (_message.Message,), {
  'DESCRIPTOR' : _CSVFILESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.CsvFileSpec)
  })
_sym_db.RegisterMessage(CsvFileSpec)

DataInputSpec = _reflection.GeneratedProtocolMessageType('DataInputSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATAINPUTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataInputSpec)
  })
_sym_db.RegisterMessage(DataInputSpec)

DataLocation = _reflection.GeneratedProtocolMessageType('DataLocation', (_message.Message,), {
  'DESCRIPTOR' : _DATALOCATION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation)
  })
_sym_db.RegisterMessage(DataLocation)

DataOutputSpec = _reflection.GeneratedProtocolMessageType('DataOutputSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATAOUTPUTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataOutputSpec)
  })
_sym_db.RegisterMessage(DataOutputSpec)

DataPipeline = _reflection.GeneratedProtocolMessageType('DataPipeline', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline)
  })
_sym_db.RegisterMessage(DataPipeline)

DataPipelineList = _reflection.GeneratedProtocolMessageType('DataPipelineList', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINELIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineList)
  })
_sym_db.RegisterMessage(DataPipelineList)

DataPipelineRun = _reflection.GeneratedProtocolMessageType('DataPipelineRun', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINERUN,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun)
  })
_sym_db.RegisterMessage(DataPipelineRun)

DataPipelineRunCondition = _reflection.GeneratedProtocolMessageType('DataPipelineRunCondition', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINERUNCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunCondition)
  })
_sym_db.RegisterMessage(DataPipelineRunCondition)

DataPipelineRunList = _reflection.GeneratedProtocolMessageType('DataPipelineRunList', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINERUNLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunList)
  })
_sym_db.RegisterMessage(DataPipelineRunList)

DataPipelineRunSpec = _reflection.GeneratedProtocolMessageType('DataPipelineRunSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINERUNSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunSpec)
  })
_sym_db.RegisterMessage(DataPipelineRunSpec)

DataPipelineRunStatus = _reflection.GeneratedProtocolMessageType('DataPipelineRunStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINERUNSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunStatus)
  })
_sym_db.RegisterMessage(DataPipelineRunStatus)

DataPipelineSpec = _reflection.GeneratedProtocolMessageType('DataPipelineSpec', (_message.Message,), {

  'DatasetSelectorEntry' : _reflection.GeneratedProtocolMessageType('DatasetSelectorEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATAPIPELINESPEC_DATASETSELECTORENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineSpec.DatasetSelectorEntry)
    })
  ,
  'DESCRIPTOR' : _DATAPIPELINESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineSpec)
  })
_sym_db.RegisterMessage(DataPipelineSpec)
_sym_db.RegisterMessage(DataPipelineSpec.DatasetSelectorEntry)

DataPipelineStatus = _reflection.GeneratedProtocolMessageType('DataPipelineStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATAPIPELINESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineStatus)
  })
_sym_db.RegisterMessage(DataPipelineStatus)

DataProduct = _reflection.GeneratedProtocolMessageType('DataProduct', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct)
  })
_sym_db.RegisterMessage(DataProduct)

DataProductList = _reflection.GeneratedProtocolMessageType('DataProductList', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductList)
  })
_sym_db.RegisterMessage(DataProductList)

DataProductSpec = _reflection.GeneratedProtocolMessageType('DataProductSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductSpec)
  })
_sym_db.RegisterMessage(DataProductSpec)

DataProductStatus = _reflection.GeneratedProtocolMessageType('DataProductStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductStatus)
  })
_sym_db.RegisterMessage(DataProductStatus)

DataProductVersion = _reflection.GeneratedProtocolMessageType('DataProductVersion', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTVERSION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion)
  })
_sym_db.RegisterMessage(DataProductVersion)

DataProductVersionList = _reflection.GeneratedProtocolMessageType('DataProductVersionList', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTVERSIONLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersionList)
  })
_sym_db.RegisterMessage(DataProductVersionList)

DataProductVersionSpec = _reflection.GeneratedProtocolMessageType('DataProductVersionSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTVERSIONSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersionSpec)
  })
_sym_db.RegisterMessage(DataProductVersionSpec)

DataProductVersionStatus = _reflection.GeneratedProtocolMessageType('DataProductVersionStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATAPRODUCTVERSIONSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersionStatus)
  })
_sym_db.RegisterMessage(DataProductVersionStatus)

DataSource = _reflection.GeneratedProtocolMessageType('DataSource', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource)
  })
_sym_db.RegisterMessage(DataSource)

DataSourceList = _reflection.GeneratedProtocolMessageType('DataSourceList', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCELIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceList)
  })
_sym_db.RegisterMessage(DataSourceList)

DataSourceSpec = _reflection.GeneratedProtocolMessageType('DataSourceSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceSpec)
  })
_sym_db.RegisterMessage(DataSourceSpec)

DataSourceStatus = _reflection.GeneratedProtocolMessageType('DataSourceStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceStatus)
  })
_sym_db.RegisterMessage(DataSourceStatus)

Dataset = _reflection.GeneratedProtocolMessageType('Dataset', (_message.Message,), {
  'DESCRIPTOR' : _DATASET,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset)
  })
_sym_db.RegisterMessage(Dataset)

DatasetGroupByStatus = _reflection.GeneratedProtocolMessageType('DatasetGroupByStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATASETGROUPBYSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetGroupByStatus)
  })
_sym_db.RegisterMessage(DatasetGroupByStatus)

DatasetList = _reflection.GeneratedProtocolMessageType('DatasetList', (_message.Message,), {
  'DESCRIPTOR' : _DATASETLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetList)
  })
_sym_db.RegisterMessage(DatasetList)

DatasetSpec = _reflection.GeneratedProtocolMessageType('DatasetSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATASETSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetSpec)
  })
_sym_db.RegisterMessage(DatasetSpec)

DatasetStatistics = _reflection.GeneratedProtocolMessageType('DatasetStatistics', (_message.Message,), {
  'DESCRIPTOR' : _DATASETSTATISTICS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetStatistics)
  })
_sym_db.RegisterMessage(DatasetStatistics)

DatasetStatus = _reflection.GeneratedProtocolMessageType('DatasetStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATASETSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetStatus)
  })
_sym_db.RegisterMessage(DatasetStatus)

DatasetTemplate = _reflection.GeneratedProtocolMessageType('DatasetTemplate', (_message.Message,), {
  'DESCRIPTOR' : _DATASETTEMPLATE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetTemplate)
  })
_sym_db.RegisterMessage(DatasetTemplate)

DriftThreshold = _reflection.GeneratedProtocolMessageType('DriftThreshold', (_message.Message,), {
  'DESCRIPTOR' : _DRIFTTHRESHOLD,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DriftThreshold)
  })
_sym_db.RegisterMessage(DriftThreshold)

Entity = _reflection.GeneratedProtocolMessageType('Entity', (_message.Message,), {
  'DESCRIPTOR' : _ENTITY,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity)
  })
_sym_db.RegisterMessage(Entity)

EntityCondition = _reflection.GeneratedProtocolMessageType('EntityCondition', (_message.Message,), {
  'DESCRIPTOR' : _ENTITYCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntityCondition)
  })
_sym_db.RegisterMessage(EntityCondition)

EntityList = _reflection.GeneratedProtocolMessageType('EntityList', (_message.Message,), {
  'DESCRIPTOR' : _ENTITYLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntityList)
  })
_sym_db.RegisterMessage(EntityList)

EntitySpec = _reflection.GeneratedProtocolMessageType('EntitySpec', (_message.Message,), {
  'DESCRIPTOR' : _ENTITYSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntitySpec)
  })
_sym_db.RegisterMessage(EntitySpec)

EntityStatus = _reflection.GeneratedProtocolMessageType('EntityStatus', (_message.Message,), {
  'DESCRIPTOR' : _ENTITYSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.EntityStatus)
  })
_sym_db.RegisterMessage(EntityStatus)

ExcelNotebookSpec = _reflection.GeneratedProtocolMessageType('ExcelNotebookSpec', (_message.Message,), {
  'DESCRIPTOR' : _EXCELNOTEBOOKSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ExcelNotebookSpec)
  })
_sym_db.RegisterMessage(ExcelNotebookSpec)

ExcelSheetArea = _reflection.GeneratedProtocolMessageType('ExcelSheetArea', (_message.Message,), {
  'DESCRIPTOR' : _EXCELSHEETAREA,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ExcelSheetArea)
  })
_sym_db.RegisterMessage(ExcelSheetArea)

FeatureGroup = _reflection.GeneratedProtocolMessageType('FeatureGroup', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREGROUP,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup)
  })
_sym_db.RegisterMessage(FeatureGroup)

FeatureGroupList = _reflection.GeneratedProtocolMessageType('FeatureGroupList', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREGROUPLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroupList)
  })
_sym_db.RegisterMessage(FeatureGroupList)

FeatureGroupSpec = _reflection.GeneratedProtocolMessageType('FeatureGroupSpec', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREGROUPSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroupSpec)
  })
_sym_db.RegisterMessage(FeatureGroupSpec)

FeatureGroupStatus = _reflection.GeneratedProtocolMessageType('FeatureGroupStatus', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREGROUPSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroupStatus)
  })
_sym_db.RegisterMessage(FeatureGroupStatus)

FeatureHistogram = _reflection.GeneratedProtocolMessageType('FeatureHistogram', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREHISTOGRAM,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram)
  })
_sym_db.RegisterMessage(FeatureHistogram)

FeatureHistogramList = _reflection.GeneratedProtocolMessageType('FeatureHistogramList', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREHISTOGRAMLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramList)
  })
_sym_db.RegisterMessage(FeatureHistogramList)

FeatureHistogramSpec = _reflection.GeneratedProtocolMessageType('FeatureHistogramSpec', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREHISTOGRAMSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramSpec)
  })
_sym_db.RegisterMessage(FeatureHistogramSpec)

FeatureHistogramStatus = _reflection.GeneratedProtocolMessageType('FeatureHistogramStatus', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREHISTOGRAMSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramStatus)
  })
_sym_db.RegisterMessage(FeatureHistogramStatus)

FlatFileFormatSpec = _reflection.GeneratedProtocolMessageType('FlatFileFormatSpec', (_message.Message,), {
  'DESCRIPTOR' : _FLATFILEFORMATSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FlatFileFormatSpec)
  })
_sym_db.RegisterMessage(FlatFileFormatSpec)

GaugeSpec = _reflection.GeneratedProtocolMessageType('GaugeSpec', (_message.Message,), {
  'DESCRIPTOR' : _GAUGESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GaugeSpec)
  })
_sym_db.RegisterMessage(GaugeSpec)

GitLocation = _reflection.GeneratedProtocolMessageType('GitLocation', (_message.Message,), {
  'DESCRIPTOR' : _GITLOCATION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GitLocation)
  })
_sym_db.RegisterMessage(GitLocation)

GovernanceReviewStatus = _reflection.GeneratedProtocolMessageType('GovernanceReviewStatus', (_message.Message,), {
  'DESCRIPTOR' : _GOVERNANCEREVIEWSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceReviewStatus)
  })
_sym_db.RegisterMessage(GovernanceReviewStatus)

GovernanceSpec = _reflection.GeneratedProtocolMessageType('GovernanceSpec', (_message.Message,), {
  'DESCRIPTOR' : _GOVERNANCESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceSpec)
  })
_sym_db.RegisterMessage(GovernanceSpec)

GovernanceStatus = _reflection.GeneratedProtocolMessageType('GovernanceStatus', (_message.Message,), {
  'DESCRIPTOR' : _GOVERNANCESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GovernanceStatus)
  })
_sym_db.RegisterMessage(GovernanceStatus)

GroupBySpec = _reflection.GeneratedProtocolMessageType('GroupBySpec', (_message.Message,), {
  'DESCRIPTOR' : _GROUPBYSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GroupBySpec)
  })
_sym_db.RegisterMessage(GroupBySpec)

GroupDatasetLocationsSpec = _reflection.GeneratedProtocolMessageType('GroupDatasetLocationsSpec', (_message.Message,), {
  'DESCRIPTOR' : _GROUPDATASETLOCATIONSSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.GroupDatasetLocationsSpec)
  })
_sym_db.RegisterMessage(GroupDatasetLocationsSpec)

HistogramSpec = _reflection.GeneratedProtocolMessageType('HistogramSpec', (_message.Message,), {
  'DESCRIPTOR' : _HISTOGRAMSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.HistogramSpec)
  })
_sym_db.RegisterMessage(HistogramSpec)

ImageLocation = _reflection.GeneratedProtocolMessageType('ImageLocation', (_message.Message,), {
  'DESCRIPTOR' : _IMAGELOCATION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ImageLocation)
  })
_sym_db.RegisterMessage(ImageLocation)

KPI = _reflection.GeneratedProtocolMessageType('KPI', (_message.Message,), {
  'DESCRIPTOR' : _KPI,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.KPI)
  })
_sym_db.RegisterMessage(KPI)

LabelingRule = _reflection.GeneratedProtocolMessageType('LabelingRule', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGRULE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingRule)
  })
_sym_db.RegisterMessage(LabelingRule)

LabelingSpec = _reflection.GeneratedProtocolMessageType('LabelingSpec', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingSpec)
  })
_sym_db.RegisterMessage(LabelingSpec)

LineChartSpec = _reflection.GeneratedProtocolMessageType('LineChartSpec', (_message.Message,), {
  'DESCRIPTOR' : _LINECHARTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LineChartSpec)
  })
_sym_db.RegisterMessage(LineChartSpec)

MaterializationSpec = _reflection.GeneratedProtocolMessageType('MaterializationSpec', (_message.Message,), {
  'DESCRIPTOR' : _MATERIALIZATIONSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.MaterializationSpec)
  })
_sym_db.RegisterMessage(MaterializationSpec)

MetricSpec = _reflection.GeneratedProtocolMessageType('MetricSpec', (_message.Message,), {
  'DESCRIPTOR' : _METRICSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.MetricSpec)
  })
_sym_db.RegisterMessage(MetricSpec)

OutlierStat = _reflection.GeneratedProtocolMessageType('OutlierStat', (_message.Message,), {
  'DESCRIPTOR' : _OUTLIERSTAT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.OutlierStat)
  })
_sym_db.RegisterMessage(OutlierStat)

PageSpec = _reflection.GeneratedProtocolMessageType('PageSpec', (_message.Message,), {
  'DESCRIPTOR' : _PAGESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.PageSpec)
  })
_sym_db.RegisterMessage(PageSpec)

ParquetFileSpec = _reflection.GeneratedProtocolMessageType('ParquetFileSpec', (_message.Message,), {
  'DESCRIPTOR' : _PARQUETFILESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ParquetFileSpec)
  })
_sym_db.RegisterMessage(ParquetFileSpec)

Recipe = _reflection.GeneratedProtocolMessageType('Recipe', (_message.Message,), {
  'DESCRIPTOR' : _RECIPE,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe)
  })
_sym_db.RegisterMessage(Recipe)

RecipeInputSpec = _reflection.GeneratedProtocolMessageType('RecipeInputSpec', (_message.Message,), {
  'DESCRIPTOR' : _RECIPEINPUTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeInputSpec)
  })
_sym_db.RegisterMessage(RecipeInputSpec)

RecipeList = _reflection.GeneratedProtocolMessageType('RecipeList', (_message.Message,), {
  'DESCRIPTOR' : _RECIPELIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeList)
  })
_sym_db.RegisterMessage(RecipeList)

RecipeOutputSpec = _reflection.GeneratedProtocolMessageType('RecipeOutputSpec', (_message.Message,), {
  'DESCRIPTOR' : _RECIPEOUTPUTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeOutputSpec)
  })
_sym_db.RegisterMessage(RecipeOutputSpec)

RecipePartSpec = _reflection.GeneratedProtocolMessageType('RecipePartSpec', (_message.Message,), {
  'DESCRIPTOR' : _RECIPEPARTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipePartSpec)
  })
_sym_db.RegisterMessage(RecipePartSpec)

RecipeRun = _reflection.GeneratedProtocolMessageType('RecipeRun', (_message.Message,), {
  'DESCRIPTOR' : _RECIPERUN,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun)
  })
_sym_db.RegisterMessage(RecipeRun)

RecipeRunList = _reflection.GeneratedProtocolMessageType('RecipeRunList', (_message.Message,), {
  'DESCRIPTOR' : _RECIPERUNLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRunList)
  })
_sym_db.RegisterMessage(RecipeRunList)

RecipeRunSpec = _reflection.GeneratedProtocolMessageType('RecipeRunSpec', (_message.Message,), {
  'DESCRIPTOR' : _RECIPERUNSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRunSpec)
  })
_sym_db.RegisterMessage(RecipeRunSpec)

RecipeRunStatus = _reflection.GeneratedProtocolMessageType('RecipeRunStatus', (_message.Message,), {
  'DESCRIPTOR' : _RECIPERUNSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRunStatus)
  })
_sym_db.RegisterMessage(RecipeRunStatus)

RecipeSpec = _reflection.GeneratedProtocolMessageType('RecipeSpec', (_message.Message,), {
  'DESCRIPTOR' : _RECIPESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeSpec)
  })
_sym_db.RegisterMessage(RecipeSpec)

RecipeStatus = _reflection.GeneratedProtocolMessageType('RecipeStatus', (_message.Message,), {
  'DESCRIPTOR' : _RECIPESTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeStatus)
  })
_sym_db.RegisterMessage(RecipeStatus)

RecipeStep = _reflection.GeneratedProtocolMessageType('RecipeStep', (_message.Message,), {
  'DESCRIPTOR' : _RECIPESTEP,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeStep)
  })
_sym_db.RegisterMessage(RecipeStep)

RecipeStepParam = _reflection.GeneratedProtocolMessageType('RecipeStepParam', (_message.Message,), {
  'DESCRIPTOR' : _RECIPESTEPPARAM,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeStepParam)
  })
_sym_db.RegisterMessage(RecipeStepParam)

RecommendationSchema = _reflection.GeneratedProtocolMessageType('RecommendationSchema', (_message.Message,), {
  'DESCRIPTOR' : _RECOMMENDATIONSCHEMA,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecommendationSchema)
  })
_sym_db.RegisterMessage(RecommendationSchema)

RelationshipSpec = _reflection.GeneratedProtocolMessageType('RelationshipSpec', (_message.Message,), {
  'DESCRIPTOR' : _RELATIONSHIPSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RelationshipSpec)
  })
_sym_db.RegisterMessage(RelationshipSpec)

RowSpec = _reflection.GeneratedProtocolMessageType('RowSpec', (_message.Message,), {
  'DESCRIPTOR' : _ROWSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RowSpec)
  })
_sym_db.RegisterMessage(RowSpec)

SampleSpec = _reflection.GeneratedProtocolMessageType('SampleSpec', (_message.Message,), {
  'DESCRIPTOR' : _SAMPLESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SampleSpec)
  })
_sym_db.RegisterMessage(SampleSpec)

ScatterPlotSpec = _reflection.GeneratedProtocolMessageType('ScatterPlotSpec', (_message.Message,), {
  'DESCRIPTOR' : _SCATTERPLOTSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.ScatterPlotSpec)
  })
_sym_db.RegisterMessage(ScatterPlotSpec)

Schema = _reflection.GeneratedProtocolMessageType('Schema', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMA,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Schema)
  })
_sym_db.RegisterMessage(Schema)

SyntheticSpec = _reflection.GeneratedProtocolMessageType('SyntheticSpec', (_message.Message,), {
  'DESCRIPTOR' : _SYNTHETICSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SyntheticSpec)
  })
_sym_db.RegisterMessage(SyntheticSpec)

TableSpec = _reflection.GeneratedProtocolMessageType('TableSpec', (_message.Message,), {
  'DESCRIPTOR' : _TABLESPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.TableSpec)
  })
_sym_db.RegisterMessage(TableSpec)

TimeSeriesSchema = _reflection.GeneratedProtocolMessageType('TimeSeriesSchema', (_message.Message,), {
  'DESCRIPTOR' : _TIMESERIESSCHEMA,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.TimeSeriesSchema)
  })
_sym_db.RegisterMessage(TimeSeriesSchema)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1'
  _DATAPIPELINESPEC_DATASETSELECTORENTRY._options = None
  _DATAPIPELINESPEC_DATASETSELECTORENTRY._serialized_options = b'8\001'
  _BARCHARTSPEC._serialized_start=394
  _BARCHARTSPEC._serialized_end=481
  _COLUMN._serialized_start=484
  _COLUMN._serialized_end=1412
  _COLUMNHISTOGRAM._serialized_start=1415
  _COLUMNHISTOGRAM._serialized_end=1639
  _COLUMNSPEC._serialized_start=1642
  _COLUMNSPEC._serialized_end=1771
  _COLUMNSTATISTICS._serialized_start=1774
  _COLUMNSTATISTICS._serialized_end=2716
  _COMPONENTSPEC._serialized_start=2719
  _COMPONENTSPEC._serialized_end=2869
  _COMPONENTVIEW._serialized_start=2872
  _COMPONENTVIEW._serialized_end=3483
  _CORRELATION._serialized_start=3485
  _CORRELATION._serialized_end=3565
  _CORRELATIONSPEC._serialized_start=3567
  _CORRELATIONSPEC._serialized_end=3629
  _CSVFILESPEC._serialized_start=3632
  _CSVFILESPEC._serialized_end=3899
  _DATAINPUTSPEC._serialized_start=3902
  _DATAINPUTSPEC._serialized_end=4038
  _DATALOCATION._serialized_start=4041
  _DATALOCATION._serialized_end=4259
  _DATAOUTPUTSPEC._serialized_start=4262
  _DATAOUTPUTSPEC._serialized_end=4527
  _DATAPIPELINE._serialized_start=4530
  _DATAPIPELINE._serialized_end=4788
  _DATAPIPELINELIST._serialized_start=4791
  _DATAPIPELINELIST._serialized_end=4958
  _DATAPIPELINERUN._serialized_start=4961
  _DATAPIPELINERUN._serialized_end=5228
  _DATAPIPELINERUNCONDITION._serialized_start=5231
  _DATAPIPELINERUNCONDITION._serialized_end=5392
  _DATAPIPELINERUNLIST._serialized_start=5395
  _DATAPIPELINERUNLIST._serialized_end=5568
  _DATAPIPELINERUNSPEC._serialized_start=5571
  _DATAPIPELINERUNSPEC._serialized_end=5899
  _DATAPIPELINERUNSTATUS._serialized_start=5902
  _DATAPIPELINERUNSTATUS._serialized_end=6411
  _DATAPIPELINESPEC._serialized_start=6414
  _DATAPIPELINESPEC._serialized_end=7182
  _DATAPIPELINESPEC_DATASETSELECTORENTRY._serialized_start=7128
  _DATAPIPELINESPEC_DATASETSELECTORENTRY._serialized_end=7182
  _DATAPIPELINESTATUS._serialized_start=7185
  _DATAPIPELINESTATUS._serialized_end=7499
  _DATAPRODUCT._serialized_start=7502
  _DATAPRODUCT._serialized_end=7757
  _DATAPRODUCTLIST._serialized_start=7760
  _DATAPRODUCTLIST._serialized_end=7925
  _DATAPRODUCTSPEC._serialized_start=7928
  _DATAPRODUCTSPEC._serialized_end=9158
  _DATAPRODUCTSTATUS._serialized_start=9161
  _DATAPRODUCTSTATUS._serialized_end=9714
  _DATAPRODUCTVERSION._serialized_start=9717
  _DATAPRODUCTVERSION._serialized_end=9993
  _DATAPRODUCTVERSIONLIST._serialized_start=9996
  _DATAPRODUCTVERSIONLIST._serialized_end=10175
  _DATAPRODUCTVERSIONSPEC._serialized_start=10178
  _DATAPRODUCTVERSIONSPEC._serialized_end=10338
  _DATAPRODUCTVERSIONSTATUS._serialized_start=10341
  _DATAPRODUCTVERSIONSTATUS._serialized_end=10574
  _DATASOURCE._serialized_start=10577
  _DATASOURCE._serialized_end=10829
  _DATASOURCELIST._serialized_start=10832
  _DATASOURCELIST._serialized_end=10995
  _DATASOURCESPEC._serialized_start=10998
  _DATASOURCESPEC._serialized_end=11780
  _DATASOURCESTATUS._serialized_start=11783
  _DATASOURCESTATUS._serialized_end=12121
  _DATASET._serialized_start=12124
  _DATASET._serialized_end=12367
  _DATASETGROUPBYSTATUS._serialized_start=12370
  _DATASETGROUPBYSTATUS._serialized_end=12594
  _DATASETLIST._serialized_start=12597
  _DATASETLIST._serialized_end=12754
  _DATASETSPEC._serialized_start=12757
  _DATASETSPEC._serialized_end=14345
  _DATASETSTATISTICS._serialized_start=14348
  _DATASETSTATISTICS._serialized_end=14693
  _DATASETSTATUS._serialized_start=14696
  _DATASETSTATUS._serialized_end=15729
  _DATASETTEMPLATE._serialized_start=15732
  _DATASETTEMPLATE._serialized_end=15898
  _DRIFTTHRESHOLD._serialized_start=15900
  _DRIFTTHRESHOLD._serialized_end=15947
  _ENTITY._serialized_start=15950
  _ENTITY._serialized_end=16190
  _ENTITYCONDITION._serialized_start=16193
  _ENTITYCONDITION._serialized_end=16345
  _ENTITYLIST._serialized_start=16348
  _ENTITYLIST._serialized_end=16503
  _ENTITYSPEC._serialized_start=16506
  _ENTITYSPEC._serialized_end=16658
  _ENTITYSTATUS._serialized_start=16661
  _ENTITYSTATUS._serialized_end=16835
  _EXCELNOTEBOOKSPEC._serialized_start=16838
  _EXCELNOTEBOOKSPEC._serialized_end=17031
  _EXCELSHEETAREA._serialized_start=17033
  _EXCELSHEETAREA._serialized_end=17140
  _FEATUREGROUP._serialized_start=17143
  _FEATUREGROUP._serialized_end=17401
  _FEATUREGROUPLIST._serialized_start=17404
  _FEATUREGROUPLIST._serialized_end=17571
  _FEATUREGROUPSPEC._serialized_start=17574
  _FEATUREGROUPSPEC._serialized_end=18535
  _FEATUREGROUPSTATUS._serialized_start=18538
  _FEATUREGROUPSTATUS._serialized_end=19182
  _FEATUREHISTOGRAM._serialized_start=19185
  _FEATUREHISTOGRAM._serialized_end=19455
  _FEATUREHISTOGRAMLIST._serialized_start=19458
  _FEATUREHISTOGRAMLIST._serialized_end=19633
  _FEATUREHISTOGRAMSPEC._serialized_start=19636
  _FEATUREHISTOGRAMSPEC._serialized_end=20265
  _FEATUREHISTOGRAMSTATUS._serialized_start=20268
  _FEATUREHISTOGRAMSTATUS._serialized_end=20809
  _FLATFILEFORMATSPEC._serialized_start=20812
  _FLATFILEFORMATSPEC._serialized_end=21106
  _GAUGESPEC._serialized_start=21108
  _GAUGESPEC._serialized_end=21185
  _GITLOCATION._serialized_start=21187
  _GITLOCATION._serialized_end=21273
  _GOVERNANCEREVIEWSTATUS._serialized_start=21275
  _GOVERNANCEREVIEWSTATUS._serialized_end=21394
  _GOVERNANCESPEC._serialized_start=21397
  _GOVERNANCESPEC._serialized_end=21538
  _GOVERNANCESTATUS._serialized_start=21541
  _GOVERNANCESTATUS._serialized_end=21879
  _GROUPBYSPEC._serialized_start=21881
  _GROUPBYSPEC._serialized_end=21974
  _GROUPDATASETLOCATIONSSPEC._serialized_start=21977
  _GROUPDATASETLOCATIONSSPEC._serialized_end=22171
  _HISTOGRAMSPEC._serialized_start=22173
  _HISTOGRAMSPEC._serialized_end=22234
  _IMAGELOCATION._serialized_start=22236
  _IMAGELOCATION._serialized_end=22297
  _KPI._serialized_start=22299
  _KPI._serialized_end=22333
  _LABELINGRULE._serialized_start=22335
  _LABELINGRULE._serialized_end=22398
  _LABELINGSPEC._serialized_start=22401
  _LABELINGSPEC._serialized_end=22626
  _LINECHARTSPEC._serialized_start=22628
  _LINECHARTSPEC._serialized_end=22702
  _MATERIALIZATIONSPEC._serialized_start=22705
  _MATERIALIZATIONSPEC._serialized_end=22967
  _METRICSPEC._serialized_start=22969
  _METRICSPEC._serialized_end=23047
  _OUTLIERSTAT._serialized_start=23049
  _OUTLIERSTAT._serialized_end=23109
  _PAGESPEC._serialized_start=23111
  _PAGESPEC._serialized_end=23198
  _PARQUETFILESPEC._serialized_start=23200
  _PARQUETFILESPEC._serialized_end=23233
  _RECIPE._serialized_start=23236
  _RECIPE._serialized_end=23476
  _RECIPEINPUTSPEC._serialized_start=23479
  _RECIPEINPUTSPEC._serialized_end=23619
  _RECIPELIST._serialized_start=23622
  _RECIPELIST._serialized_end=23777
  _RECIPEOUTPUTSPEC._serialized_start=23780
  _RECIPEOUTPUTSPEC._serialized_end=23928
  _RECIPEPARTSPEC._serialized_start=23930
  _RECIPEPARTSPEC._serialized_end=23986
  _RECIPERUN._serialized_start=23989
  _RECIPERUN._serialized_end=24238
  _RECIPERUNLIST._serialized_start=24241
  _RECIPERUNLIST._serialized_end=24402
  _RECIPERUNSPEC._serialized_start=24405
  _RECIPERUNSPEC._serialized_end=24754
  _RECIPERUNSTATUS._serialized_start=24757
  _RECIPERUNSTATUS._serialized_end=25159
  _RECIPESPEC._serialized_start=25162
  _RECIPESPEC._serialized_end=25783
  _RECIPESTATUS._serialized_start=25786
  _RECIPESTATUS._serialized_end=26049
  _RECIPESTEP._serialized_start=26051
  _RECIPESTEP._serialized_end=26166
  _RECIPESTEPPARAM._serialized_start=26168
  _RECIPESTEPPARAM._serialized_end=26214
  _RECOMMENDATIONSCHEMA._serialized_start=26216
  _RECOMMENDATIONSCHEMA._serialized_end=26304
  _RELATIONSHIPSPEC._serialized_start=26306
  _RELATIONSHIPSPEC._serialized_end=26388
  _ROWSPEC._serialized_start=26390
  _ROWSPEC._serialized_end=26479
  _SAMPLESPEC._serialized_start=26481
  _SAMPLESPEC._serialized_end=26587
  _SCATTERPLOTSPEC._serialized_start=26589
  _SCATTERPLOTSPEC._serialized_end=26649
  _SCHEMA._serialized_start=26652
  _SCHEMA._serialized_end=26956
  _SYNTHETICSPEC._serialized_start=26958
  _SYNTHETICSPEC._serialized_end=27004
  _TABLESPEC._serialized_start=27007
  _TABLESPEC._serialized_end=27139
  _TIMESERIESSCHEMA._serialized_start=27141
  _TIMESERIESSCHEMA._serialized_end=27205
# @@protoc_insertion_point(module_scope)
